<?php

global $loginbox_text;
$loginbox_text = array (

'username'				=>	'Username',
'password'				=>	'Password',
'login'					=>	'Login!',

// Added in 0.9.6
'rememberme'				=>	'Ricordami', 

// Added in 0.9.7
'lostpassword'				=>	'Hai perso la password?',

);
?>
